==> purchase-assist-domain-0.0.7-sources.jar: com/xforceplus/purchaserassist/entity/InvoiceUsedVehicle.java <==
package com.xforceplus.purchaserassist.entity;

import java.math.BigDecimal;
import com.baomidou.mybatisplus.annotation.TableName;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-03-17
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@TableName("invoiceUsedVehicle")
public class InvoiceUsedVehicle implements Serializable {

  private static final long serialVersionUID=1L;

  private String registerNo;

  private String stamper;

  private String licensePlateNo;

  private String identificationNumber;

  private String invoiceCode;

  private String invoiceNo;

  private String invoiceCodeP;

  private String invoiceNoP;

  private String invoiceType;

  private BigDecimal totalAmountTaxNum;

  private BigDecimal totalAmount;

  private BigDecimal totalTax;

  private BigDecimal taxRate;

  private String paperDrewDate;

  private String drawer;

  private String sellerName;

  private String sellerAddr;

  private String sellerTel;

  private String sellerBank;

  private String sellerBankNo;

  private String sellerIdCode;

  private String vehicleManagementOffice;

  private String companyTaxNo;

  private String companyName;

  private String companyAddr;

  private String companyBank;

  private String companyBankNo;

  private String marketName;

  private String marketBank;

  private String marketBankNo;

  private String marketTaxNo;

  private String purchaserTaxNo;

  private String purchaserName;

  private String purchaserAddr;

  private String purchaserTel;

  private String purchaserIdCode;

  private String codeOfTheCompetentTaxAuthority;

  private String nameOfTheCompetentTaxAuthority;

  private String taxPaidProof;

  private String qrcode;

  private String vehiclesType;

  private String machineCode;

  private String checkCode;

  private String sku;

  private String cipherList;

  private LocalDateTime invoiceTime;

  private Long userId;

  private Long collectionId;

  private Integer status;

  private String imgUrl;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private String createUser;

  private String updateUser;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;




        }

==> purchase-assist-domain-0.0.14-sources.jar: com/xforceplus/purchaserassist/entity/InvoiceUsedVehicle.java <==
package com.xforceplus.purchaserassist.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-04-02
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class InvoiceUsedVehicle implements Serializable {

  private static final long serialVersionUID=1L;

  private String registerNo;

  private String stamper;

  private String licensePlateNo;

  private String identificationNumber;

  private String invoiceCode;

  private String invoiceNo;

  private String invoiceCodeP;

  private String invoiceNoP;

  private String invoiceType;

  private BigDecimal totalAmountTaxNum;

  private BigDecimal totalAmount;

  private BigDecimal totalTax;

  private BigDecimal taxRate;

  private String paperDrewDate;

  private String drawer;

  private String sellerName;

  private String sellerAddr;

  private String sellerTel;

  private String sellerBank;

  private String sellerBankNo;

  private String sellerIdCode;

  private String vehicleManagementOffice;

  private String companyTaxNo;

  private String companyName;

  private String companyAddr;

  private String companyBank;

  private String companyBankNo;

  private String marketName;

  private String marketBank;

  private String marketBankNo;

  private String marketTaxNo;

  private String purchaserTaxNo;

  private String purchaserName;

  private String purchaserAddr;

  private String purchaserTel;

  private String purchaserIdCode;

  private String codeOfTheCompetentTaxAuthority;

  private String nameOfTheCompetentTaxAuthority;

  private String taxPaidProof;

  private String qrcode;

  private String vehiclesType;

  private String machineCode;

  private String checkCode;

  private String sku;

  private String cipherList;

  private LocalDateTime invoiceTime;

  private Long userId;

  private Long collectionId;

  private Integer status;

  private String imgUrl;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;




        }
